@@ -56,7 +56,7 @@ def serialize(obj):
 
 class KeycloakAdmin:
 
-    def __init__(self, server_url, username, password, realm_name='master', client_id='admin-cli', client_secret_key=None, verify=True):
+    def __init__(self, server_url, username, password, realm_name='master', client_id='admin-cli', client_secret_key=None, verify=True, timeout=60):
         """
 
         :param server_url: Keycloak server url
@@ -81,7 +81,7 @@ class KeycloakAdmin:
         self._connection = ConnectionManager(base_url=server_url,
                                              headers={'Authorization': 'Bearer ' + self.token.get('access_token'),
                                                       'Content-Type': 'application/json'},
-                                             timeout=60,
+                                             timeout=timeout,
                                              verify=verify)
 
     @property
